@@ -63,10 +63,11 @@ namespace {
 
 std::string ExtractFolderTitle(const std::string& title)
 {
-  std::regex pattern("[sS]\\.?[0-9]+ ?[eE][pP]?\\.?[0-9]+/?[0-9]* *");
+  std::regex pattern(" *[sS]\\.?[0-9]+ ?[eE][pP]?\\.?[0-9]+/?[0-9]*");
   std::stringstream result;
   std::regex_replace(std::ostream_iterator<char>(result), title.begin(), title.end(), pattern, "");
-  const std::string folderTitle = result.str();
+  std::string folderTitle = result.str();
+  StringUtils::Trim(folderTitle);
 
   if (title != folderTitle)
     return folderTitle;
